## 国际指数

接口：index_global，可以通过数据工具调试和查看数据。

描述：获取国际主要指数日线行情

限量：单次最大提取4000行情数据，可循环获取，总量不限制

积分：用户积6000积分可调取，积分越高频次越高，请自行提高积分，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS指数代码，见下表 |
| trade_date | str | N | 交易日期，YYYYMMDD格式，下同 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

| TS指数代码 | 指数名称 |
| --- | --- |
| XIN9 | 富时中国A50指数  (富时A50) |
| HSI | 恒生指数 |
| HKTECH | 恒生科技指数 |
| HKAH | 恒生AH股H指数 |
| DJI | 道琼斯工业指数 |
| SPX | 标普500指数 |
| IXIC | 纳斯达克指数 |
| FTSE | 富时100指数 |
| FCHI | 法国CAC40指数 |
| GDAXI | 德国DAX指数 |
| N225 | 日经225指数 |
| KS11 | 韩国综合指数 |
| AS51 | 澳大利亚标普200指数 |
| SENSEX | 印度孟买SENSEX指数 |
| IBOVESPA | 巴西IBOVESPA指数 |
| RTS | 俄罗斯RTS指数 |
| TWII | 台湾加权指数 |
| CKLSE | 马来西亚指数 |
| SPTSX | 加拿大S&P/TSX指数 |
| CSX5P | STOXX欧洲50指数 |
| RUT | 罗素2000指数 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS指数代码 |
| trade_date | str | Y | 交易日 |
| open | float | Y | 开盘点位 |
| close | float | Y | 收盘点位 |
| high | float | Y | 最高点位 |
| low | float | Y | 最低点位 |
| pre_close | float | Y | 昨日收盘点 |
| change | float | Y | 涨跌点位 |
| pct_chg | float | Y | 涨跌幅 |
| swing | float | Y | 振幅 |
| vol | float | Y | 成交量 （大部分无此项数据） |
| amount | float | N | 成交额 （大部分无此项数据） |

接口使用

```python
pro = ts.pro_api()

#获取富时中国50指数
df = pro.index_global(ts_code='XIN9', start_date='20200201', end_date='20200220')
```

数据示例

```python
trade_date    open     close    high    low       pre_close  change  \
0    20200220  13750.45  14009.40  14023.88  13750.45   13750.45  258.95   
```